####################################################
DRO helper for Water Space Dungeon is a discord bot
with a static data base with answers of Water Space
Dungeon for all days of the year
####################################################